Offspring creators
==================

.. _crossover_api:

Crossover
---------

.. autosummary::
   :nosignatures:

   ase_ga.element_crossovers
   ase_ga.cutandsplicepairing
   ase_ga.particle_crossovers
   ase_ga.slab_operators

.. _mutation_api:
   
Mutation
--------

.. autosummary::
   :nosignatures:

   ase_ga.element_mutations
   ase_ga.particle_mutations
   ase_ga.soft_mutation
   ase_ga.standardmutations

Documentation
-------------
   
.. automodule:: ase_ga.element_crossovers
   :members:
   :member-order: bysource

.. automodule:: ase_ga.element_mutations
   :members:
   :member-order: bysource
                  
.. automodule:: ase_ga.cutandsplicepairing
   :members:
   :member-order: bysource
                  
.. automodule:: ase_ga.standardmutations
   :members:
   :member-order: bysource
                  
.. automodule:: ase_ga.slab_operators
   :members:
   :member-order: bysource
                  
.. automodule:: ase_ga.particle_crossovers
   :members:
   :member-order: bysource
                  
.. automodule:: ase_ga.particle_mutations
   :members:
   :member-order: bysource
                  
.. automodule:: ase_ga.slab_operators
   :members:
   :member-order: bysource
   
.. automodule:: ase_ga.soft_mutation
   :members:
   :member-order: bysource
   
                  
